summaryrefslogtreecommitdiffstats
path: root/tdeio/tdefile
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-02-07 17:56:54 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-02-07 17:56:54 -0600
commit546d2312d9b4a09110dd2d87fc7f07b330f7ce95 (patch)
tree4cab8f565db447b9898a3ea9e6f606aca6ded84e /tdeio/tdefile
parent696e36a06178f50483432b9a8e806c4a1c530921 (diff)
downloadtdelibs-546d2312d9b4a09110dd2d87fc7f07b330f7ce95.tar.gz
tdelibs-546d2312d9b4a09110dd2d87fc7f07b330f7ce95.zip
Rename KComp to avoid conflicts with KDE4
Diffstat (limited to 'tdeio/tdefile')
-rw-r--r--tdeio/tdefile/kdiroperator.h16
-rw-r--r--tdeio/tdefile/kpropertiesdialog.cpp14
-rw-r--r--tdeio/tdefile/kurlrequester.cpp2
3 files changed, 16 insertions, 16 deletions
diff --git a/tdeio/tdefile/kpropertiesdialog.cpp b/tdeio/tdefile/kpropertiesdialog.cpp
index 2b8fd1814..9d4ee6534 100644
--- a/tdeio/tdefile/kpropertiesdialog.cpp
+++ b/tdeio/tdefile/kpropertiesdialog.cpp
@@ -1749,8 +1749,8 @@ KFilePermissionsPropsPlugin::KFilePermissionsPropsPlugin( KPropertiesDialog *_pr
if (IamRoot && isLocal)
{
usrEdit = new KLineEdit( gb );
- KCompletion *kcom = usrEdit->completionObject();
- kcom->setOrder(KCompletion::Sorted);
+ TDECompletion *kcom = usrEdit->completionObject();
+ kcom->setOrder(TDECompletion::Sorted);
setpwent();
for (i=0; ((user = getpwent()) != 0L) && (i < maxEntries); i++)
kcom->addItem(TQString::fromLatin1(user->pw_name));
@@ -1829,7 +1829,7 @@ KFilePermissionsPropsPlugin::KFilePermissionsPropsPlugin( KPropertiesDialog *_pr
if (IamRoot && isLocal)
{
grpEdit = new KLineEdit(gb);
- KCompletion *kcom = new KCompletion;
+ TDECompletion *kcom = new TDECompletion;
kcom->setItems(groupList);
grpEdit->setCompletionObject(kcom, true);
grpEdit->setAutoDeleteCompletionObject( true );
@@ -3487,8 +3487,8 @@ void KDesktopPropsPlugin::slotAdvanced()
w->dcopCombo->setCurrentItem(0);
// Provide username completion up to 1000 users.
- KCompletion *kcom = new KCompletion;
- kcom->setOrder(KCompletion::Sorted);
+ TDECompletion *kcom = new TDECompletion;
+ kcom->setOrder(TDECompletion::Sorted);
struct passwd *pw;
int i, maxEntries = 1000;
setpwent();
@@ -3761,8 +3761,8 @@ KExecPropsPlugin::KExecPropsPlugin( KPropertiesDialog *_props )
enableSuidEdit();
// Provide username completion up to 1000 users.
- KCompletion *kcom = new KCompletion;
- kcom->setOrder(KCompletion::Sorted);
+ TDECompletion *kcom = new TDECompletion;
+ kcom->setOrder(TDECompletion::Sorted);
struct passwd *pw;
int i, maxEntries = 1000;
setpwent();
diff --git a/tdeio/tdefile/kurlrequester.cpp b/tdeio/tdefile/kurlrequester.cpp
index 1d5bf009e..9a76a69a6 100644
--- a/tdeio/tdefile/kurlrequester.cpp
+++ b/tdeio/tdefile/kurlrequester.cpp
@@ -124,7 +124,7 @@ public:
receiver, TQT_SIGNAL( returnPressed( const TQString& ) ));
}
- void setCompletionObject( KCompletion *comp ) {
+ void setCompletionObject( TDECompletion *comp ) {
if ( combo )
combo->setCompletionObject( comp );
else
diff --git a/tdeio/tdefile/kdiroperator.h b/tdeio/tdefile/kdiroperator.h
index ca850b733..95bf5c5ba 100644
--- a/tdeio/tdefile/kdiroperator.h
+++ b/tdeio/tdefile/kdiroperator.h
@@ -319,27 +319,27 @@ class TDEIO_EXPORT KDirOperator : public TQWidget
int numFiles() const;
/**
* @returns a KCompletion object, containing all filenames and
* directories of the current directory/URL.
* You can use it to insert it into a KLineEdit or KComboBox
* Note: it will only contain files, after prepareCompletionObjects()
* has been called. It will be implicitly called from makeCompletion()
* or makeDirCompletion()
*/
- KCompletion * completionObject() const {
- return const_cast<KCompletion *>( &myCompletion );
+ TDECompletion * completionObject() const {
+ return const_cast<TDECompletion *>( &myCompletion );
}
/**
* @returns a KCompletion object, containing only all directories of the
* current directory/URL.
* You can use it to insert it into a KLineEdit or KComboBox
* Note: it will only contain directories, after
* prepareCompletionObjects() has been called. It will be implicitly
* called from makeCompletion() or makeDirCompletion()
*/
- KCompletion *dirCompletionObject() const {
- return const_cast<KCompletion *>( &myDirCompletion );
+ TDECompletion *dirCompletionObject() const {
+ return const_cast<TDECompletion *>( &myDirCompletion );
}
/**
@@ -838,8 +838,8 @@ private:
KDirLister *dir;
KURL currUrl;
- KCompletion myCompletion;
- KCompletion myDirCompletion;
+ TDECompletion myCompletion;
+ TDECompletion myDirCompletion;
bool myCompleteListDirty;
TQDir::SortSpec mySorting;
@@ -319,27 +319,27 @@ class TDEIO_EXPORT KDirOperator : public TQWidget
int numFiles() const;
/**
- * @returns a KCompletion object, containing all filenames and
+ * @returns a TDECompletion object, containing all filenames and
* directories of the current directory/URL.
* You can use it to insert it into a KLineEdit or KComboBox
@@ -319,27 +319,27 @@ class TDEIO_EXPORT KDirOperator : public TQWidget
}
/**
- * @returns a KCompletion object, containing only all directories of the
+ * @returns a TDECompletion object, containing only all directories of the
* current directory/URL.
* You can use it to insert it into a KLineEdit or KComboBox